Primitive floating point mathematical functions commonly found in Math, FastMath, and the likes. Vectorized counterparts can be found in the [[vect-math]] namespace.
Primitive floating point mathematical functions commonly found in Math, FastMath, and the likes. Vectorized counterparts can be found in the [[vect-math]] namespace.
(cdf-norm-inv x)The inverse CDF of Normal(0,1).
The inverse CDF of Normal(0,1).
(erf x)Error function: erf(x) = 2/√π 0∫x e-t2dt.
Error function: erf(x) = 2/√π 0∫x e-t2dt.
(erfc x)The complementary error function: erfc(x) = 1 - erf(x).
The complementary error function: erfc(x) = 1 - erf(x).
(erfc-inv x)Inverse complementary error function.
Inverse complementary error function.
(gamma x)Gamma function: http://en.wikipedia.org/wiki/Gamma_function
Gamma function: http://en.wikipedia.org/wiki/Gamma_function
(lgamma x)Natural logarithm of the Gamma function: http://en.wikipedia.org/wiki/Gamma_function#The_log-gamma_function
Natural logarithm of the Gamma function: http://en.wikipedia.org/wiki/Gamma_function#The_log-gamma_function
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |