Vectorized floating point mathematical functions commonly found in Math, FastMath, and the likes. Primitive scalar counterparts can be found in the [[math]] namespace.
Vectorized floating point mathematical functions commonly found in Math, FastMath, and the likes. Primitive scalar counterparts can be found in the [[math]] namespace.
(linear-frac a shifta)(linear-frac scalea a shifta)(linear-frac scalea a shifta scaleb b shiftb)(linear-frac! a shifta)(linear-frac! scalea a shifta)(linear-frac! scalea a shifta y)(linear-frac! scalea a shifta scaleb b shiftb y)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |